@@ -265,6 +265,9 @@ class Client(commandServer, encrypt, Desktop):
     # private user directories
     privateDirs = []
 
+    def init(self):
+        self.domainnames = {}
+
     def removeVars(self):
         """
         Remove domain variables. Useing on remove package
@@ -291,12 +294,11 @@ class Client(commandServer, encrypt, Desktop):
         cache_method = self.clVars.Get('cl_cifs_cache')
         domain = self.clVars.Get('cl_remote_domain') or \
             self.get_server_domainname(host)
-        cifs_mount_vers = self.clVars.Get('cl_cifs_mount_vers')
         if not uid is None:
             # mount by uid
             p = process(mountCmd, "-t", "cifs", "-o",
                         "cache=%s,domain=%s,user=%s,uid=%d,gid=%d,noperm%s" % (
-                            cache_method, domain, cifs_mount_vers,
+                            cache_method, domain, 
                             userName, uid, gid, nomapposix),
                         "//%s/%s" % (host, res), rpath,
                         envdict={"PASSWD": userPwd}, stderr=STDOUT)
@@ -304,18 +306,18 @@ class Client(commandServer, encrypt, Desktop):
         else:
             p = process(mountCmd, "-t", "cifs", "-o",
                         "cache=%s,domain=%s,vers=%s,user=%s%s" % (cache_method,
-                            cifs_mount_vers, domain, userName, nomapposix),
+                            domain, userName, nomapposix),
                         "//%s/%s" % (host, res), rpath,
                         envdict={"PASSWD": userPwd}, stderr=STDOUT)
             return p.success()
 
     def get_server_domainname(self, host):
-        if host not in self._domainnames:
+        if host not in self.domainnames:
             try:
-                self._domainnames[host] = Samba().get_server_domainname(host)
+                self.domainnames[host] = Samba().get_server_domainname(host)
             except SambaError as e:
                 raise ClientError(str(e))
-        return self._domainnames[host]
+        return self.domainnames[host]
 
     def mountSleepRes(self, host, userName, userPwd, res, rpath, uid=None,
                       gid=None):
